@@ -12,6 +12,7 @@ from urllib3.util import Retry
 
 from .error import RequestError, RequestSetupError
 from .resources import (
+    Balances,
     Chargebacks,
     Clients,
     Customers,
@@ -53,6 +54,7 @@ class Client(object):
     client_id: str = ""
     client_secret: str = ""
     set_token: Callable[[dict], None]
+    testmode: bool = False
 
     @staticmethod
     def validate_api_endpoint(api_endpoint: str) -> str:
@@ -104,6 +106,7 @@ class Client(object):
         self.onboarding = Onboarding(self)
         self.settlements = Settlements(self)
         self.subscriptions = Subscriptions(self)
+        self.balances = Balances(self)
 
         # compose base user agent string
         self.user_agent_components = OrderedDict()
@@ -121,11 +124,13 @@ class Client(object):
 
     def set_access_token(self, access_token: str) -> None:
         self.api_key = self.validate_access_token(access_token)
-        self.set_user_agent_component("OAuth", "2.0", sanitize=False)  # keep spelling equal to the PHP client
 
     def set_timeout(self, timeout: Union[int, Tuple[int, int]]) -> None:
         self.timeout = timeout
 
+    def set_testmode(self, testmode: bool) -> None:
+        self.testmode = testmode
+
     def set_user_agent_component(self, key: str, value: str, sanitize: bool = True) -> None:
         """Add or replace new user-agent component strings.
 
@@ -167,6 +172,13 @@ class Client(object):
             except TypeError as err:
                 raise RequestSetupError(f"Error encoding data into JSON: {err}.")
 
+        if params is None:
+            params = {}
+        if self.testmode and "testmode" not in params:
+            if not (self.api_key.startswith("access_") or hasattr(self, "_oauth_client")):
+                raise RequestSetupError("Configuring testmode only works with access_token or OAuth authorization")
+            params["testmode"] = "true"
+
         querystring = generate_querystring(params)
         if querystring:
             url += "?" + querystring
@@ -180,6 +192,7 @@ class Client(object):
         path: str,
         data: Optional[Dict[str, Any]] = None,
         params: Optional[Dict[str, Any]] = None,
+        idempotency_key: str = "",
     ) -> requests.Response:
         if not self.api_key:
             raise RequestSetupError("You have not set an API key. Please use set_api_key() to set the API key.")
@@ -191,22 +204,29 @@ class Client(object):
 
         url, payload, params = self._format_request_data(path, data, params)
         try:
+
+            headers = {
+                "Accept": "application/json",
+                "Authorization": f"Bearer {self.api_key}",
+                "Content-Type": "application/json",
+                "User-Agent": self.user_agent,
+                "X-Mollie-Client-Info": self.UNAME,
+            }
+
+            if idempotency_key:
+                headers.update({"Idempotency-Key": idempotency_key})
+
             response = self._client.request(
                 method=http_method,
                 url=url,
-                headers={
-                    "Accept": "application/json",
-                    "Authorization": f"Bearer {self.api_key}",
-                    "Content-Type": "application/json",
-                    "User-Agent": self.user_agent,
-                    "X-Mollie-Client-Info": self.UNAME,
-                },
+                headers=headers,
                 params=params,
                 data=payload,
                 timeout=self.timeout,
             )
         except requests.exceptions.RequestException as err:
             raise RequestError(f"Unable to communicate with Mollie: {err}")
+
         return response
 
     def _perform_http_call_oauth(
@@ -215,18 +235,25 @@ class Client(object):
         path: str,
         data: Optional[Dict[str, Any]] = None,
         params: Optional[Dict[str, Any]] = None,
+        idempotency_key: str = "",
     ) -> requests.Response:
         url, payload, params = self._format_request_data(path, data, params)
         try:
+
+            headers = {
+                "Accept": "application/json",
+                "Content-Type": "application/json",
+                "User-Agent": self.user_agent,
+                "X-Mollie-Client-Info": self.UNAME,
+            }
+
+            if idempotency_key:
+                headers.update({"Idempotency-Key": idempotency_key})
+
             response = self._oauth_client.request(
                 method=http_method,
                 url=url,
-                headers={
-                    "Accept": "application/json",
-                    "Content-Type": "application/json",
-                    "User-Agent": self.user_agent,
-                    "X-Mollie-Client-Info": self.UNAME,
-                },
+                headers=headers,
                 params=params,
                 data=payload,
                 timeout=self.timeout,
@@ -241,11 +268,16 @@ class Client(object):
         path: str,
         data: Optional[Dict[str, Any]] = None,
         params: Optional[Dict[str, Any]] = None,
+        idempotency_key: str = "",
     ) -> requests.Response:
         if hasattr(self, "_oauth_client"):
-            return self._perform_http_call_oauth(http_method, path, data=data, params=params)
+            return self._perform_http_call_oauth(
+                http_method, path, data=data, params=params, idempotency_key=idempotency_key
+            )
         else:
-            return self._perform_http_call_apikey(http_method, path, data=data, params=params)
+            return self._perform_http_call_apikey(
+                http_method, path, data=data, params=params, idempotency_key=idempotency_key
+            )
 
     def setup_oauth(
         self,
