@@ -4,7 +4,7 @@ from .base import ObjectBase
 class Onboarding(ObjectBase):
     @classmethod
     def get_resource_class(cls, client):
-        from ..resources.onboarding import Onboarding as OnboardingResource
+        from ..resources import Onboarding as OnboardingResource
 
         return OnboardingResource(client)
 
@@ -36,17 +36,6 @@ class Onboarding(ObjectBase):
     def can_receive_settlements(self):
         return self._get_property("canReceiveSettlements")
 
-    @property
-    def organization(self):
-        """Retrieve organization for an onboarding."""
-        from .organization import Organization
-
-        url = self._get_link("organization")
-
-        if url:
-            resp = self.client.organizations.perform_api_call(self.client.organizations.REST_READ, url)
-            return Organization(resp)
-
     def is_needs_data(self):
         return self.status == self.STATUS_NEEDS_DATA
 
@@ -55,3 +44,9 @@ class Onboarding(ObjectBase):
 
     def is_completed(self):
         return self.status == self.STATUS_COMPLETED
+
+    def get_organization(self):
+        """Retrieve the related organization."""
+        url = self._get_link("organization")
+        if url:
+            return self.client.organizations.from_url(url)
